@@ -3,7 +3,7 @@ use std::fmt;
 use std::path::{PathBuf, Path};
 
 use semver::Version;
-use rustc_serialize::{Encoder, Encodable};
+use serde::ser;
 
 use core::{Dependency, PackageId, Summary, SourceId, PackageIdSpec};
 use core::WorkspaceConfig;
@@ -112,58 +112,69 @@ pub enum TargetKind {
     CustomBuild,
 }
 
-impl Encodable for TargetKind {
-    fn encode<S: Encoder>(&self, s: &mut S) -> Result<(), S::Error> {
+impl TargetKind {
+    /// Returns a vector of crate types as specified in a manifest
+    pub fn crate_types(&self) -> Vec<&str> {
+        use self::TargetKind::*;
         match *self {
-            TargetKind::Lib(ref kinds) |
-            TargetKind::ExampleLib(ref kinds) => {
+            Lib(ref kinds) | ExampleLib(ref kinds) => {
                 kinds.iter().map(LibKind::crate_type).collect()
             }
-            TargetKind::Bin => vec!["bin"],
-            TargetKind::ExampleBin => vec!["example"],
-            TargetKind::Test => vec!["test"],
-            TargetKind::CustomBuild => vec!["custom-build"],
-            TargetKind::Bench => vec!["bench"],
-        }.encode(s)
+            Bin => vec!["bin"],
+            ExampleBin => vec!["example"],
+            Test => vec!["test"],
+            CustomBuild => vec!["custom-build"],
+            Bench => vec!["bench"]
+        }
     }
 }
 
-#[derive(Clone, PartialEq, Eq, Debug, Hash)]
+impl ser::Serialize for TargetKind {
+    fn serialize<S>(&self, s: S) -> Result<S::Ok, S::Error>
+        where S: ser::Serializer,
+    {
+        use self::TargetKind::*;
+        match *self {
+            Lib(ref kinds) => kinds.iter().map(LibKind::crate_type).collect(),
+            Bin => vec!["bin"],
+            ExampleBin | ExampleLib(_) => vec!["example"],
+            Test => vec!["test"],
+            CustomBuild => vec!["custom-build"],
+            Bench => vec!["bench"]
+        }.serialize(s)
+    }
+}
+
+
+// Note that most of the fields here are skipped when serializing because we
+// don't want to export them just yet (becomes a public API of Cargo). Others
+// though are definitely needed!
+#[derive(Clone, PartialEq, Eq, Debug, Hash, Serialize)]
 pub struct Profile {
     pub opt_level: String,
+    #[serde(skip_serializing)]
     pub lto: bool,
+    #[serde(skip_serializing)]
     pub codegen_units: Option<u32>,    // None = use rustc default
+    #[serde(skip_serializing)]
     pub rustc_args: Option<Vec<String>>,
+    #[serde(skip_serializing)]
     pub rustdoc_args: Option<Vec<String>>,
     pub debuginfo: Option<u32>,
     pub debug_assertions: bool,
+    #[serde(skip_serializing)]
     pub rpath: bool,
     pub test: bool,
+    #[serde(skip_serializing)]
     pub doc: bool,
+    #[serde(skip_serializing)]
     pub run_custom_build: bool,
+    #[serde(skip_serializing)]
     pub check: bool,
+    #[serde(skip_serializing)]
     pub panic: Option<String>,
 }
 
-#[derive(RustcEncodable)]
-struct SerializedProfile<'a> {
-    opt_level: &'a str,
-    debuginfo: Option<u32>,
-    debug_assertions: bool,
-    test: bool,
-}
-
-impl Encodable for Profile {
-    fn encode<S: Encoder>(&self, s: &mut S) -> Result<(), S::Error> {
-        SerializedProfile {
-            opt_level: &self.opt_level,
-            debuginfo: self.debuginfo,
-            debug_assertions: self.debug_assertions,
-            test: self.test,
-        }.encode(s)
-    }
-}
-
 #[derive(Default, Clone, Debug, PartialEq, Eq)]
 pub struct Profiles {
     pub release: Profile,
@@ -185,6 +196,7 @@ pub struct Target {
     kind: TargetKind,
     name: String,
     src_path: PathBuf,
+    required_features: Option<Vec<String>>,
     tested: bool,
     benched: bool,
     doc: bool,
@@ -193,20 +205,22 @@ pub struct Target {
     for_host: bool,
 }
 
-#[derive(RustcEncodable)]
+#[derive(Serialize)]
 struct SerializedTarget<'a> {
     kind: &'a TargetKind,
+    crate_types: Vec<&'a str>,
     name: &'a str,
-    src_path: &'a str,
+    src_path: &'a PathBuf,
 }
 
-impl Encodable for Target {
-    fn encode<S: Encoder>(&self, s: &mut S) -> Result<(), S::Error> {
+impl ser::Serialize for Target {
+    fn serialize<S: ser::Serializer>(&self, s: S) -> Result<S::Ok, S::Error> {
         SerializedTarget {
             kind: &self.kind,
+            crate_types: self.kind.crate_types(),
             name: &self.name,
-            src_path: &self.src_path.display().to_string(),
-        }.encode(s)
+            src_path: &self.src_path,
+        }.serialize(s)
     }
 }
 
@@ -305,6 +319,7 @@ impl Target {
             kind: TargetKind::Bin,
             name: String::new(),
             src_path: src_path,
+            required_features: None,
             doc: false,
             doctest: false,
             harness: true,
@@ -326,10 +341,12 @@ impl Target {
         }
     }
 
-    pub fn bin_target(name: &str, src_path: PathBuf) -> Target {
+    pub fn bin_target(name: &str, src_path: PathBuf,
+                      required_features: Option<Vec<String>>) -> Target {
         Target {
             kind: TargetKind::Bin,
             name: name.to_string(),
+            required_features: required_features,
             doc: true,
             ..Target::with_path(src_path)
         }
@@ -349,7 +366,8 @@ impl Target {
 
     pub fn example_target(name: &str,
                           crate_targets: Vec<LibKind>,
-                          src_path: PathBuf) -> Target {
+                          src_path: PathBuf,
+                          required_features: Option<Vec<String>>) -> Target {
         let kind = if crate_targets.is_empty() {
             TargetKind::ExampleBin
         } else {
@@ -359,24 +377,29 @@ impl Target {
         Target {
             kind: kind,
             name: name.to_string(),
+            required_features: required_features,
             benched: false,
             ..Target::with_path(src_path)
         }
     }
 
-    pub fn test_target(name: &str, src_path: PathBuf) -> Target {
+    pub fn test_target(name: &str, src_path: PathBuf,
+                       required_features: Option<Vec<String>>) -> Target {
         Target {
             kind: TargetKind::Test,
             name: name.to_string(),
+            required_features: required_features,
             benched: false,
             ..Target::with_path(src_path)
         }
     }
 
-    pub fn bench_target(name: &str, src_path: PathBuf) -> Target {
+    pub fn bench_target(name: &str, src_path: PathBuf,
+                        required_features: Option<Vec<String>>) -> Target {
         Target {
             kind: TargetKind::Bench,
             name: name.to_string(),
+            required_features: required_features,
             tested: false,
             ..Target::with_path(src_path)
         }
@@ -385,6 +408,7 @@ impl Target {
     pub fn name(&self) -> &str { &self.name }
     pub fn crate_name(&self) -> String { self.name.replace("-", "_") }
     pub fn src_path(&self) -> &Path { &self.src_path }
+    pub fn required_features(&self) -> Option<&Vec<String>> { self.required_features.as_ref() }
     pub fn kind(&self) -> &TargetKind { &self.kind }
     pub fn tested(&self) -> bool { self.tested }
     pub fn harness(&self) -> bool { self.harness }
