@@ -5,12 +5,12 @@ use std::hash;
 use std::path::{Path, PathBuf};
 
 use semver::Version;
+use serde::ser;
 
 use core::{Dependency, Manifest, PackageId, SourceId, Target};
 use core::{Summary, SourceMap};
 use ops;
 use util::{CargoResult, Config, LazyCell, ChainError, internal, human, lev_distance};
-use rustc_serialize::{Encoder,Encodable};
 
 /// Information about a package that is available somewhere in the file system.
 ///
@@ -24,13 +24,14 @@ pub struct Package {
     manifest_path: PathBuf,
 }
 
-#[derive(RustcEncodable)]
+#[derive(Serialize)]
 struct SerializedPackage<'a> {
     name: &'a str,
     version: &'a str,
     id: &'a PackageId,
     license: Option<&'a str>,
     license_file: Option<&'a str>,
+    description: Option<&'a str>,
     source: &'a SourceId,
     dependencies: &'a [Dependency],
     targets: &'a [Target],
@@ -38,13 +39,16 @@ struct SerializedPackage<'a> {
     manifest_path: &'a str,
 }
 
-impl Encodable for Package {
-    fn encode<S: Encoder>(&self, s: &mut S) -> Result<(), S::Error> {
+impl ser::Serialize for Package {
+    fn serialize<S>(&self, s: S) -> Result<S::Ok, S::Error>
+        where S: ser::Serializer,
+    {
         let summary = self.manifest.summary();
         let package_id = summary.package_id();
         let manmeta = self.manifest.metadata();
         let license = manmeta.license.as_ref().map(String::as_ref);
         let license_file = manmeta.license_file.as_ref().map(String::as_ref);
+        let description = manmeta.description.as_ref().map(String::as_ref);
 
         SerializedPackage {
             name: &package_id.name(),
@@ -52,12 +56,13 @@ impl Encodable for Package {
             id: package_id,
             license: license,
             license_file: license_file,
+            description: description,
             source: summary.source_id(),
             dependencies: summary.dependencies(),
             targets: &self.manifest.targets(),
             features: summary.features(),
             manifest_path: &self.manifest_path.display().to_string(),
-        }.encode(s)
+        }.serialize(s)
     }
 }
 
