@@ -3,6 +3,9 @@
 
 #[cfg(test)] extern crate hamcrest;
 #[macro_use] extern crate log;
+#[macro_use] extern crate serde_derive;
+#[macro_use] extern crate serde_json;
+extern crate chrono;
 extern crate crates_io as registry;
 extern crate crossbeam;
 extern crate curl;
@@ -15,9 +18,10 @@ extern crate glob;
 extern crate libc;
 extern crate libgit2_sys;
 extern crate num_cpus;
-extern crate regex;
 extern crate rustc_serialize;
 extern crate semver;
+extern crate serde;
+extern crate serde_ignored;
 extern crate shell_escape;
 extern crate tar;
 extern crate tempdir;
@@ -27,8 +31,8 @@ extern crate url;
 
 use std::io;
 use std::fmt;
-use rustc_serialize::{Decodable, Encodable};
-use rustc_serialize::json;
+use rustc_serialize::Decodable;
+use serde::ser;
 use docopt::Docopt;
 
 use core::{Shell, MultiShell, ShellConfig, Verbosity, ColorConfig};
@@ -37,6 +41,8 @@ use term::color::{BLACK};
 
 pub use util::{CargoError, CargoResult, CliError, CliResult, human, Config, ChainError};
 
+pub const CARGO_ENV: &'static str = "CARGO";
+
 macro_rules! bail {
     ($($fmt:tt)*) => (
         return Err(::util::human(&format_args!($($fmt)*)))
@@ -57,8 +63,6 @@ pub struct CommitInfo {
 pub struct CfgInfo {
     // Information about the git repository we may have been built from.
     pub commit_info: Option<CommitInfo>,
-    // The date that the build was performed.
-    pub build_date: String,
     // The release channel we were built for.
     pub release_channel: String,
 }
@@ -75,29 +79,20 @@ pub struct VersionInfo {
 
 impl fmt::Display for VersionInfo {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        write!(f, "cargo-{}.{}.{}",
+        write!(f, "cargo {}.{}.{}",
                self.major, self.minor, self.patch)?;
-        match self.cfg_info.as_ref().map(|ci| &ci.release_channel) {
-            Some(channel) => {
-                if channel != "stable" {
-                    write!(f, "-{}", channel)?;
-                    let empty = String::from("");
-                    write!(f, "{}", self.pre_release.as_ref().unwrap_or(&empty))?;
-                }
-            },
-            None => (),
+        if let Some(channel) = self.cfg_info.as_ref().map(|ci| &ci.release_channel) {
+            if channel != "stable" {
+                write!(f, "-{}", channel)?;
+                let empty = String::from("");
+                write!(f, "{}", self.pre_release.as_ref().unwrap_or(&empty))?;
+            }
         };
 
         if let Some(ref cfg) = self.cfg_info {
-            match cfg.commit_info {
-                Some(ref ci) => {
-                    write!(f, " ({} {})",
-                           ci.short_commit_hash, ci.commit_date)?;
-                },
-                None => {
-                    write!(f, " (built {})",
-                           cfg.build_date)?;
-                }
+            if let Some(ref ci) = cfg.commit_info {
+                write!(f, " ({} {})",
+                       ci.short_commit_hash, ci.commit_date)?;
             }
         };
         Ok(())
@@ -124,17 +119,8 @@ pub fn call_main_without_stdin<Flags: Decodable>(
     exec(flags, config)
 }
 
-// This will diverge if `result` is an `Err` and return otherwise.
-pub fn process_executed(result: CliResult, shell: &mut MultiShell)
-{
-    match result {
-        Err(e) => handle_cli_error(e, shell),
-        Ok(()) => {}
-    }
-}
-
-pub fn print_json<T: Encodable>(obj: &T) {
-    let encoded = json::encode(&obj).unwrap();
+pub fn print_json<T: ser::Serialize>(obj: &T) {
+    let encoded = serde_json::to_string(&obj).unwrap();
     println!("{}", encoded);
 }
 
@@ -183,8 +169,8 @@ pub fn shell(verbosity: Verbosity, color_config: ColorConfig) -> MultiShell {
     }
 }
 
-pub fn handle_cli_error(err: CliError, shell: &mut MultiShell) -> ! {
-    debug!("handle_cli_error; err={:?}", err);
+pub fn exit_with_error(err: CliError, shell: &mut MultiShell) -> ! {
+    debug!("exit_with_error; err={:?}", err);
 
     let CliError { error, exit_code, unknown } = err;
     // exit_code == 0 is non-fatal error, e.g. docopt version info
@@ -260,12 +246,11 @@ pub fn version() -> VersionInfo {
                     }
                 });
             VersionInfo {
-                major: option_env_str!("CFG_VERSION_MAJOR").unwrap(),
-                minor: option_env_str!("CFG_VERSION_MINOR").unwrap(),
-                patch: option_env_str!("CFG_VERSION_PATCH").unwrap(),
-                pre_release: option_env_str!("CFG_PRERELEASE_VERSION"),
+                major: env_str!("CARGO_PKG_VERSION_MAJOR"),
+                minor: env_str!("CARGO_PKG_VERSION_MINOR"),
+                patch: env_str!("CARGO_PKG_VERSION_PATCH"),
+                pre_release: option_env_str!("CARGO_PKG_VERSION_PRE"),
                 cfg_info: Some(CfgInfo {
-                    build_date: option_env_str!("CFG_BUILD_DATE").unwrap(),
                     release_channel: option_env_str!("CFG_RELEASE_CHANNEL").unwrap(),
                     commit_info: commit_info,
                 }),
