@@ -6,7 +6,7 @@ use std::io::{self, Write};
 use std::path::{self, PathBuf};
 use std::sync::Arc;
 
-use rustc_serialize::json;
+use serde_json;
 
 use core::{Package, PackageId, PackageSet, Target, Resolve};
 use core::{Profile, Profiles, Workspace};
@@ -75,9 +75,9 @@ pub trait Executor: Send + Sync + 'static {
                  cmd: ProcessBuilder,
                  _id: &PackageId,
                  handle_stdout: &mut FnMut(&str) -> CargoResult<()>,
-                 handle_srderr: &mut FnMut(&str) -> CargoResult<()>)
+                 handle_stderr: &mut FnMut(&str) -> CargoResult<()>)
                  -> Result<(), ProcessError> {
-        cmd.exec_with_streaming(handle_stdout, handle_srderr)?;
+        cmd.exec_with_streaming(handle_stdout, handle_stderr)?;
         Ok(())
     }
 }
@@ -180,18 +180,17 @@ pub fn compile_targets<'a, 'cfg: 'a>(ws: &Workspace<'cfg>,
                 }));
         }
 
-        if let Some(feats) = cx.resolve.features(&unit.pkg.package_id()) {
-            cx.compilation.cfgs.entry(unit.pkg.package_id().clone())
-                .or_insert(HashSet::new())
-                .extend(feats.iter().map(|feat| format!("feature=\"{}\"", feat)));
-        }
+        let feats = cx.resolve.features(&unit.pkg.package_id());
+        cx.compilation.cfgs.entry(unit.pkg.package_id().clone())
+            .or_insert_with(HashSet::new)
+            .extend(feats.iter().map(|feat| format!("feature=\"{}\"", feat)));
 
         output_depinfo(&mut cx, unit)?;
     }
 
     for (&(ref pkg, _), output) in cx.build_state.outputs.lock().unwrap().iter() {
         cx.compilation.cfgs.entry(pkg.clone())
-            .or_insert(HashSet::new())
+            .or_insert_with(HashSet::new)
             .extend(output.cfgs.iter().cloned());
 
         for dir in output.library_paths.iter() {
@@ -229,11 +228,9 @@ fn compile<'a, 'cfg: 'a>(cx: &mut Context<'a, 'cfg>,
         } else {
             rustc(cx, unit, exec.clone())?
         };
-        let link_work1 = link_targets(cx, unit)?;
-        let link_work2 = link_targets(cx, unit)?;
         // Need to link targets on both the dirty and fresh
-        let dirty = work.then(link_work1).then(dirty);
-        let fresh = link_work2.then(fresh);
+        let dirty = work.then(link_targets(cx, unit, false)?).then(dirty);
+        let fresh = link_targets(cx, unit, true)?.then(fresh);
         (dirty, fresh, freshness)
     };
     jobs.enqueue(cx, unit, Job::new(dirty, fresh), freshness)?;
@@ -290,12 +287,6 @@ fn rustc(cx: &mut Context, unit: &Unit, exec: Arc<Executor>) -> CargoResult<Work
     let json_messages = cx.build_config.json_messages;
     let package_id = unit.pkg.package_id().clone();
     let target = unit.target.clone();
-    let profile = unit.profile.clone();
-    let features = cx.resolve.features(unit.pkg.package_id())
-                     .into_iter()
-                     .flat_map(|i| i)
-                     .map(|s| s.to_string())
-                     .collect::<Vec<_>>();
 
     exec.init(cx);
     let exec = exec.clone();
@@ -342,9 +333,9 @@ fn rustc(cx: &mut Context, unit: &Unit, exec: Arc<Executor>) -> CargoResult<Work
                 },
                 &mut |line| {
                     // stderr from rustc can have a mix of JSON and non-JSON output
-                    if line.starts_with("{") {
+                    if line.starts_with('{') {
                         // Handle JSON lines
-                        let compiler_message = json::Json::from_str(line).map_err(|_| {
+                        let compiler_message = serde_json::from_str(line).map_err(|_| {
                             internal(&format!("compiler produced invalid json: `{}`", line))
                         })?;
 
@@ -389,18 +380,6 @@ fn rustc(cx: &mut Context, unit: &Unit, exec: Arc<Executor>) -> CargoResult<Work
             fingerprint::append_current_dir(&dep_info_loc, &cwd)?;
         }
 
-        if json_messages {
-            machine_message::emit(machine_message::Artifact {
-                package_id: &package_id,
-                target: &target,
-                profile: &profile,
-                features: features,
-                filenames: filenames.iter().map(|&(ref src, _, _)| {
-                    src.display().to_string()
-                }).collect(),
-            });
-        }
-
         Ok(())
     }));
 
@@ -436,21 +415,36 @@ fn rustc(cx: &mut Context, unit: &Unit, exec: Arc<Executor>) -> CargoResult<Work
 
 /// Link the compiled target (often of form foo-{metadata_hash}) to the
 /// final target. This must happen during both "Fresh" and "Compile"
-fn link_targets(cx: &mut Context, unit: &Unit) -> CargoResult<Work> {
+fn link_targets(cx: &mut Context, unit: &Unit, fresh: bool) -> CargoResult<Work> {
     let filenames = cx.target_filenames(unit)?;
+    let package_id = unit.pkg.package_id().clone();
+    let target = unit.target.clone();
+    let profile = unit.profile.clone();
+    let features = cx.resolve.features_sorted(&package_id).into_iter()
+        .map(|s| s.to_owned())
+        .collect();
+    let json_messages = cx.build_config.json_messages;
+
     Ok(Work::new(move |_| {
         // If we're a "root crate", e.g. the target of this compilation, then we
         // hard link our outputs out of the `deps` directory into the directory
         // above. This means that `cargo build` will produce binaries in
         // `target/debug` which one probably expects.
-        for (src, link_dst, _linkable) in filenames {
+        let mut destinations = vec![];
+        for &(ref src, ref link_dst, _linkable) in filenames.iter() {
             // This may have been a `cargo rustc` command which changes the
             // output, so the source may not actually exist.
-            debug!("Thinking about linking {} to {:?}", src.display(), link_dst);
-            if !src.exists() || link_dst.is_none() {
+            if !src.exists() {
                 continue
             }
-            let dst = link_dst.unwrap();
+            let dst = match link_dst.as_ref() {
+                Some(dst) => dst,
+                None => {
+                    destinations.push(src.display().to_string());
+                    continue;
+                }
+            };
+            destinations.push(dst.display().to_string());
 
             debug!("linking {} to {}", src.display(), dst.display());
             if dst.exists() {
@@ -458,16 +452,27 @@ fn link_targets(cx: &mut Context, unit: &Unit) -> CargoResult<Work> {
                     human(format!("failed to remove: {}", dst.display()))
                 })?;
             }
-            fs::hard_link(&src, &dst)
+            fs::hard_link(src, dst)
                  .or_else(|err| {
                      debug!("hard link failed {}. falling back to fs::copy", err);
-                     fs::copy(&src, &dst).map(|_| ())
+                     fs::copy(src, dst).map(|_| ())
                  })
                  .chain_error(|| {
                      human(format!("failed to link or copy `{}` to `{}`",
                                    src.display(), dst.display()))
             })?;
         }
+
+        if json_messages {
+            machine_message::emit(machine_message::Artifact {
+                package_id: &package_id,
+                target: &target,
+                profile: &profile,
+                features: features,
+                filenames: destinations,
+                fresh: fresh,
+            });
+        }
         Ok(())
     }))
 }
@@ -531,10 +536,8 @@ fn rustdoc(cx: &mut Context, unit: &Unit) -> CargoResult<Work> {
 
     rustdoc.arg("-o").arg(doc_dir);
 
-    if let Some(features) = cx.resolve.features(unit.pkg.package_id()) {
-        for feat in features {
-            rustdoc.arg("--cfg").arg(&format!("feature=\"{}\"", feat));
-        }
+    for feat in cx.resolve.features(unit.pkg.package_id()) {
+        rustdoc.arg("--cfg").arg(&format!("feature=\"{}\"", feat));
     }
 
     if let Some(ref args) = unit.profile.rustdoc_args {
@@ -682,10 +685,8 @@ fn build_base_args(cx: &mut Context,
         cmd.arg("--cfg").arg("test");
     }
 
-    if let Some(features) = cx.resolve.features(unit.pkg.package_id()) {
-        for feat in features.iter() {
-            cmd.arg("--cfg").arg(&format!("feature=\"{}\"", feat));
-        }
+    for feat in cx.resolve.features(unit.pkg.package_id()).iter() {
+        cmd.arg("--cfg").arg(&format!("feature=\"{}\"", feat));
     }
 
     match cx.target_metadata(unit) {
