@@ -28,6 +28,7 @@ pub struct Config {
     rustc: LazyCell<Rustc>,
     values: LazyCell<HashMap<String, ConfigValue>>,
     cwd: PathBuf,
+    cargo_exe: LazyCell<PathBuf>,
     rustdoc: LazyCell<PathBuf>,
     extra_verbose: Cell<bool>,
     frozen: Cell<bool>,
@@ -44,6 +45,7 @@ impl Config {
             rustc: LazyCell::new(),
             cwd: cwd,
             values: LazyCell::new(),
+            cargo_exe: LazyCell::new(),
             rustdoc: LazyCell::new(),
             extra_verbose: Cell::new(false),
             frozen: Cell::new(false),
@@ -93,6 +95,15 @@ impl Config {
         self.rustc.get_or_try_init(|| Rustc::new(self.get_tool("rustc")?))
     }
 
+    pub fn cargo_exe(&self) -> CargoResult<&Path> {
+        self.cargo_exe.get_or_try_init(||
+            env::current_exe().and_then(|path| path.canonicalize())
+            .chain_error(|| {
+                human("couldn't get the path to cargo executable")
+            })
+        ).map(AsRef::as_ref)
+    }
+
     pub fn values(&self) -> CargoResult<&HashMap<String, ConfigValue>> {
         self.values.get_or_try_init(|| self.load_values())
     }
@@ -193,7 +204,7 @@ impl Config {
     }
 
     pub fn get_path(&self, key: &str) -> CargoResult<Option<Value<PathBuf>>> {
-        if let Some(val) = self.get_string(&key)? {
+        if let Some(val) = self.get_string(key)? {
             let is_path = val.val.contains('/') ||
                           (cfg!(windows) && val.val.contains('\\'));
             let path = if is_path {
@@ -372,13 +383,12 @@ impl Config {
         walk_tree(&self.cwd, |mut file, path| {
             let mut contents = String::new();
             file.read_to_string(&mut contents)?;
-            let table = cargo_toml::parse(&contents,
-                                               &path,
-                                               self).chain_error(|| {
+            let toml = cargo_toml::parse(&contents,
+                                         &path,
+                                         self).chain_error(|| {
                 human(format!("could not parse TOML configuration in `{}`",
                               path.display()))
             })?;
-            let toml = toml::Value::Table(table);
             let value = CV::from_toml(&path, toml).chain_error(|| {
                 human(format!("failed to load TOML configuration from `{}`",
                               path.display()))
@@ -409,13 +419,13 @@ impl Config {
     }
 }
 
-#[derive(Eq, PartialEq, Clone, RustcEncodable, RustcDecodable, Copy)]
+#[derive(Eq, PartialEq, Clone, Copy)]
 pub enum Location {
     Project,
     Global
 }
 
-#[derive(Eq,PartialEq,Clone,RustcDecodable)]
+#[derive(Eq,PartialEq,Clone,Deserialize)]
 pub enum ConfigValue {
     Integer(i64, PathBuf),
     String(String, PathBuf),
@@ -743,9 +753,11 @@ pub fn set_config(cfg: &Config,
     let mut contents = String::new();
     let _ = file.read_to_string(&mut contents);
     let mut toml = cargo_toml::parse(&contents, file.path(), cfg)?;
-    toml.insert(key.to_string(), value.into_toml());
+    toml.as_table_mut()
+        .unwrap()
+        .insert(key.to_string(), value.into_toml());
 
-    let contents = toml::Value::Table(toml).to_string();
+    let contents = toml.to_string();
     file.seek(SeekFrom::Start(0))?;
     file.write_all(contents.as_bytes())?;
     file.file().set_len(contents.len() as u64)?;
