@@ -1,5 +1,5 @@
 pub use self::cfg::{Cfg, CfgExpr};
-pub use self::config::Config;
+pub use self::config::{Config, homedir};
 pub use self::dependency_queue::{DependencyQueue, Fresh, Dirty, Freshness};
 pub use self::errors::{CargoResult, CargoError, ChainError, CliResult};
 pub use self::errors::{CliError, ProcessError, CargoTestError};
@@ -39,7 +39,6 @@ mod cfg;
 mod dependency_queue;
 mod rustc;
 mod sha256;
-mod shell_escape;
 mod vcs;
 mod lazy_cell;
 mod flock;
