@@ -70,8 +70,8 @@ pub fn without_prefix<'a>(a: &'a Path, b: &'a Path) -> Option<&'a Path> {
 pub fn read(path: &Path) -> CargoResult<String> {
     (|| -> CargoResult<_> {
         let mut ret = String::new();
-        let mut f = try!(File::open(path));
-        try!(f.read_to_string(&mut ret));
+        let mut f = File::open(path)?;
+        f.read_to_string(&mut ret)?;
         Ok(ret)
     })().map_err(human).chain_error(|| {
         human(format!("failed to read `{}`", path.display()))
@@ -81,8 +81,8 @@ pub fn read(path: &Path) -> CargoResult<String> {
 pub fn read_bytes(path: &Path) -> CargoResult<Vec<u8>> {
     (|| -> CargoResult<_> {
         let mut ret = Vec::new();
-        let mut f = try!(File::open(path));
-        try!(f.read_to_end(&mut ret));
+        let mut f = File::open(path)?;
+        f.read_to_end(&mut ret)?;
         Ok(ret)
     })().map_err(human).chain_error(|| {
         human(format!("failed to read `{}`", path.display()))
@@ -91,8 +91,8 @@ pub fn read_bytes(path: &Path) -> CargoResult<Vec<u8>> {
 
 pub fn write(path: &Path, contents: &[u8]) -> CargoResult<()> {
     (|| -> CargoResult<()> {
-        let mut f = try!(File::create(path));
-        try!(f.write_all(contents));
+        let mut f = File::create(path)?;
+        f.write_all(contents)?;
         Ok(())
     })().map_err(human).chain_error(|| {
         human(format!("failed to write `{}`", path.display()))
@@ -101,13 +101,13 @@ pub fn write(path: &Path, contents: &[u8]) -> CargoResult<()> {
 
 pub fn append(path: &Path, contents: &[u8]) -> CargoResult<()> {
     (|| -> CargoResult<()> {
-        let mut f = try!(OpenOptions::new()
-                            .write(true)
-                            .append(true)
-                            .create(true)
-                            .open(path));
+        let mut f = OpenOptions::new()
+                                 .write(true)
+                                 .append(true)
+                                 .create(true)
+                                 .open(path)?;
 
-        try!(f.write_all(contents));
+        f.write_all(contents)?;
         Ok(())
     }).chain_error(|| {
         internal(format!("failed to write `{}`", path.display()))
