@@ -6,12 +6,12 @@ extern crate hamcrest;
 extern crate tar;
 extern crate cargo;
 
-use std::fs::{File, OpenOptions};
+use std::fs::File;
 use std::io::prelude::*;
 use std::path::{Path, PathBuf};
 
 use cargotest::{cargo_process, process};
-use cargotest::support::{project, execs, paths, git, path2url, cargo_dir};
+use cargotest::support::{project, execs, paths, git, path2url, cargo_exe};
 use flate2::read::GzDecoder;
 use hamcrest::{assert_that, existing_file, contains};
 use tar::Archive;
@@ -360,9 +360,9 @@ fn no_duplicates_from_modified_tracked_files() {
             fn main() {}
         "#);
     p.build();
-    File::create(p.root().join("src/main.rs")).unwrap().write_all(r#"
+    File::create(p.root().join("src/main.rs")).unwrap().write_all(br#"
             fn main() { println!("A change!"); }
-        "#.as_bytes()).unwrap();
+        "#).unwrap();
     let mut cargo = cargo_process();
     cargo.cwd(p.root());
     assert_that(cargo.clone().arg("build"), execs().with_status(0));
@@ -476,12 +476,12 @@ fn repackage_on_source_change() {
         panic!("could not create file {}: {}", p.root().join("src/foo.rs").display(), e)
     });
 
-    file.write_all(r#"
+    file.write_all(br#"
         fn main() { println!("foo"); }
-    "#.as_bytes()).unwrap();
+    "#).unwrap();
     std::mem::drop(file);
 
-    let mut pro = process(&cargo_dir().join("cargo"));
+    let mut pro = process(&cargo_exe());
     pro.arg("package").cwd(p.root());
 
     // Check that cargo rebuilds the tarball
@@ -546,6 +546,9 @@ Caused by:
 
 #[test]
 fn do_not_package_if_repository_is_dirty() {
+    let p = project("foo");
+    p.build();
+
     // Create a Git repository containing a minimal Rust project.
     git::repo(&paths::root().join("foo"))
         .file("Cargo.toml", r#"
@@ -562,10 +565,17 @@ fn do_not_package_if_repository_is_dirty() {
         .build();
 
     // Modify Cargo.toml without committing the change.
-    let p = project("foo");
-    let manifest_path = p.root().join("Cargo.toml");
-    let mut manifest = t!(OpenOptions::new().append(true).open(manifest_path));
-    t!(writeln!(manifest, ""));
+    p.change_file("Cargo.toml", r#"
+            [project]
+            name = "foo"
+            version = "0.0.1"
+            license = "MIT"
+            description = "foo"
+            documentation = "foo"
+            homepage = "foo"
+            repository = "foo"
+            # change
+    "#);
 
     assert_that(p.cargo("package"),
                 execs().with_status(101)
