@@ -1102,6 +1102,39 @@ fn relative_path_for_member_works() {
     assert_that(p.cargo("build").cwd(p.root().join("bar")), execs().with_status(0));
 }
 
+#[test]
+fn relative_path_for_root_works() {
+    let p = project("foo")
+        .file("Cargo.toml", r#"
+        [project]
+        name = "foo"
+        version = "0.1.0"
+        authors = []
+
+        [workspace]
+
+        [dependencies]
+        subproj = { path = "./subproj" }
+    "#)
+        .file("src/main.rs", "fn main() {}")
+        .file("subproj/Cargo.toml", r#"
+        [project]
+        name = "subproj"
+        version = "0.1.0"
+        authors = []
+    "#)
+        .file("subproj/src/main.rs", "fn main() {}");
+    p.build();
+
+    assert_that(p.cargo("build").cwd(p.root())
+                    .arg("--manifest-path").arg("./Cargo.toml"),
+                execs().with_status(0));
+
+    assert_that(p.cargo("build").cwd(p.root().join("subproj"))
+                    .arg("--manifest-path").arg("../Cargo.toml"),
+                execs().with_status(0));
+}
+
 #[test]
 fn path_dep_outside_workspace_is_not_member() {
     let p = project("foo")
@@ -1227,8 +1260,7 @@ fn test_path_dependency_under_member() {
 
     assert_that(p.cargo("build").cwd(p.root().join("foo/bar")),
                 execs().with_status(0));
-    // Ideally, `foo/bar` should be a member of the workspace,
-    // because it is hierarchically under the workspace member.
-    assert_that(&p.root().join("foo/bar/Cargo.lock"), existing_file());
-    assert_that(&p.root().join("foo/bar/target"), existing_dir());
+
+    assert_that(&p.root().join("foo/bar/Cargo.lock"), is_not(existing_file()));
+    assert_that(&p.root().join("foo/bar/target"), is_not(existing_dir()));
 }
